# -*- coding: utf-8 -*-
"""
OBSERVATORIO DEL SISTEMA PRODUCTIVO VENEZOLANO

Copyleft (C) 2014 CENDITEL Nodo Mérida. http://www.cenditel.gob.ve/

"""
## @namespace cadenas.models
#
# Contiene las clases y métodos para los modelos involucrados en el módulo de cadenas
from django.db import models
from apps.comun.models import ModelReadOnly, Entidad, Municipio, Parroquia


class CodigoCiiu7(ModelReadOnly):
    """
    @note: Clase para la persistencia de los objetos con el codigo ciiu 7.
    @licence: GPLv2
    @organization: CENDITEL Nodo M?rida
    @author: Ing. Erwin Paredes.
    @date: 2010-07-07
    @sugerencia: para llenar el campo encuestado2006 ejecutar desde el motor de postgres la instruccion:
    @ update codigo_ciiu7 set encuestado2006 = 'S' where codigo_ciiu in (select distinct cod_produccion
    from encuesta_productos_terminados)
    """
    codigo_ciiu = models.CharField(max_length=7, primary_key=True)
    descripcion = models.CharField(max_length=256)
    encuestado2006 = models.CharField(max_length=2, null=True)

    class Meta(ModelReadOnly.Meta):
        db_table = u'codigo_ciiu7'
        verbose_name_plural = "Códigos CIIU 7 dig."


class CodigoUm(models.Model):
    codigo = models.SmallIntegerField(primary_key=True)
    unidad_medida = models.CharField(max_length=100)

    class Meta(ModelReadOnly.Meta):
        db_table = u'codigo_um'
        verbose_name_plural = "Códigos de la Unidad de Medida"


class Encuesta(ModelReadOnly):
    """
    @note: Clase para la persistencia de los objetos con las Unidades Economicas.
    @licence: GPLv2
    @organization: CENDITEL Nodo M?rida
    @author: Ing. Erwin Paredes.
    @date: 2010-07-07
    """
    nombre_comercial = models.CharField(max_length=100)
    razon_social = models.CharField(max_length=100)
    direccion = models.CharField(max_length=200)
    telefono1 = models.CharField(max_length=30)
    telefono2 = models.CharField(max_length=30)
    telefono3 = models.CharField(max_length=30)
    fax = models.CharField(max_length=30)
    email = models.CharField(max_length=100)
    rif = models.CharField(max_length=10, primary_key=True)

    def __str__(self):
        return u'%s' % self.nombre_comercial

    class Meta(ModelReadOnly.Meta):
        db_table = u'Encuesta'
        verbose_name_plural = "Unidades Económicas"


class EncuestaProductosTerminados(ModelReadOnly):
    """
    @note: Clase para la persistencia de los objetos de los productos terminados de las Unidades Economicas.
    @licence: GPLv2
    @organization: CENDITEL Nodo M?rida
    @author: Ing. Erwin Paredes.
    @date: 2010-07-07
    """
    rif = models.ForeignKey(Encuesta, db_column='rif')
    ciiu_3 = models.CharField(max_length=4)
    ciiu_rama_agrupada = models.CharField(max_length=4)
    inventario_inicial_cantidad = models.IntegerField()
    inventario_inicial_valor = models.IntegerField()
    produccion_cantidad = models.IntegerField()
    produccion_valor = models.TextField()  # This field type is a guess.
    ventas_internas_cantidad = models.TextField()  # This field type is a guess.
    ventas_internas_valor = models.TextField()  # This field type is a guess.
    exportaciones_cantidad = models.IntegerField()
    exportaciones_valor = models.TextField()  # This field type is a guess.
    otros_destinos_cantidad = models.IntegerField()
    otros_destinos_valor = models.TextField()  # This field type is a guess.
    inventario_final_cantidad = models.TextField()  # This field type is a guess.
    inventario_final_valor = models.TextField()  # This field type is a guess.
    cod_produccion = models.CharField(max_length=15)
    descripcion = models.CharField(max_length=100)
    codigo_um = models.ForeignKey(CodigoUm, db_column='codigo_um')

    class Meta(ModelReadOnly.Meta):
        db_table = u'encuesta_productos_terminados'
        verbose_name_plural = "Productos Terminados"


class EncuestaMateriaPrima(ModelReadOnly):
    """
    @note: Clase para la persistencia de los objetos con la materia prima de las Unidades Economicas.
    @licence: GPLv2
    @organization: CENDITEL Nodo M?rida
    @author: Ing. Erwin Paredes.
    @date: 2010-07-07
    """
    rif = models.ForeignKey(Encuesta, db_column='rif')
    ciiu_3 = models.CharField(max_length=4)
    ciiu_rama_agrupada = models.CharField(max_length=4)
    origen_insumo = models.SmallIntegerField()
    inventario_inicial_cantidad = models.IntegerField()
    inventario_inicial_valor = models.IntegerField()
    compras_cantidad = models.IntegerField()
    compras_valor = models.IntegerField()
    perdidas_cantidad = models.IntegerField()
    perdidas_valor = models.IntegerField()
    ventas_sin_transformar_cantidad = models.IntegerField()
    ventas_sin_transformar_valor = models.IntegerField()
    otros_destinos_cantidad = models.IntegerField()
    otros_destinos_valor = models.IntegerField()
    inventario_final_cantidad = models.IntegerField()
    inventario_final_valor = models.IntegerField()
    cod_producto = models.CharField(max_length=15)
    descripcion = models.CharField(max_length=100)
    codigo_um = models.ForeignKey(CodigoUm, db_column='codigo_um')

    class Meta(ModelReadOnly.Meta):
        db_table = u'encuesta_materia_prima'
        verbose_name_plural = "Materia Prima"


class Directorio2005(ModelReadOnly):
    """
    @note: Clase para la persistencia de los objetos Directorio del a?o 2005.
    @licence: GPLv2
    @organization: CENDITEL Nodo M?rida
    @author: Ing. Erwin Paredes.
    @date: 2010-07-07
    """
    rif = models.CharField(max_length=10, primary_key=True)
    codigoempresa = models.CharField(max_length=6, null=True, verbose_name='Código de la Empresa')
    nombregrupo = models.CharField(max_length=100, null=True, verbose_name='Grupo/Consorcio')
    #entidad = models.CharField(max_length=2, null=True, verbose_name = 'Estado')
    entidad = models.ForeignKey(Entidad, db_column='entidad_codigo')
    planilla = models.CharField(max_length=5, null=True, verbose_name='Planilla')
    #municipio = models.CharField(max_length=4, null=True, verbose_name = 'Municipio')
    municipio = models.ForeignKey(Municipio, db_column='municipio_codigo')
    #parroquia = models.CharField(max_length=6, null=True, verbose_name = 'Parroquia')
    parroquia = models.ForeignKey(Parroquia, db_column='parroquia_codigo')
    segmento = models.CharField(max_length=4, null=True, verbose_name='Segmento')
    manzana = models.CharField(max_length=4, null=True, verbose_name='Manzana')
    nombreestablecimiento = models.CharField(max_length=255, null=True, verbose_name='Nombre Establecimiento')
    razonsocial = models.CharField(max_length=255, null=True, verbose_name='Razón Social')
    direccion = models.CharField(max_length=255, null=True, verbose_name='Dirección')
    codigoarea = models.CharField(max_length=4, null=True, verbose_name='Código de Area')
    email = models.CharField(max_length=100, null=True, verbose_name='E-mail')
    telefono1 = models.CharField(max_length=15, null=True, verbose_name='Telefono')
    telefono2 = models.CharField(max_length=15, null=True, verbose_name='Telefono')
    telefono3 = models.CharField(max_length=15, null=True, verbose_name='Telefono')
    fax = models.CharField(max_length=15, null=True, verbose_name='Fax')
    empleados = models.IntegerField(null=True, verbose_name='No. Empleados')
    obreros = models.IntegerField(null=True, verbose_name='No. Obreros')
    totalpersonal = models.IntegerField(null=True, verbose_name='Total Personal')
    estrato = models.CharField(max_length=4, null=True, verbose_name='Estrato')
    ciiu3principal = models.CharField(max_length=4, null=True, verbose_name='CIIU Principal')
    ciiu3secundario = models.CharField(max_length=4, null=True, verbose_name='CIIU Secundario')
    entidadgerencia = models.CharField(max_length=2, null=True, verbose_name='Estado (Gerencia)')
    direcciongerencia = models.CharField(max_length=255, null=True, verbose_name='Dirección (Gerencia)')
    codigoareagerencia = models.CharField(max_length=4, null=True, verbose_name='Código de Area (Gerencia)')
    telefono1g = models.CharField(max_length=15, null=True, verbose_name='Telefono (Gerencia)')
    telefono2g = models.CharField(max_length=15, null=True, verbose_name='Telefono (Gerencia)')
    telefono3g = models.CharField(max_length=15, null=True, verbose_name='Telefono (Gerencia)')
    faxg = models.CharField(max_length=15, null=True, verbose_name='Fax (Gerencia)')
    identificacion = models.CharField(max_length=50, null=True, verbose_name='Identificación')
    mesfundada = models.CharField(max_length=2, null=True, verbose_name='Mes de Fundada')
    anosfundada = models.CharField(max_length=4, null=True, verbose_name='Año de Fundada')
    encuestada2006 = models.CharField(max_length=5, null=False)

    def __str__(self):
        return u'%s - %s' % (self.rif, self.nombreestablecimiento)

    class Meta(ModelReadOnly.Meta):
        db_table = u'directorio2005'
        verbose_name_plural = "Directorio 2005"